pub struct NormalizePathLayer { /* private fields */ }Expand description
重新导出 tower-http 的常用中间件
Layer that applies NormalizePath which normalizes paths.
See the module docs for more details.
Implementations
Sourceimpl NormalizePathLayer
impl NormalizePathLayer
Sourcepub fn trim_trailing_slash() -> NormalizePathLayer
pub fn trim_trailing_slash() -> NormalizePathLayer
Create a new NormalizePathLayer.
Any trailing slashes from request paths will be removed. For example, a request with /foo/
will be changed to /foo before reaching the inner service.
Sourcepub fn append_trailing_slash() -> NormalizePathLayer
pub fn append_trailing_slash() -> NormalizePathLayer
Create a new NormalizePathLayer.
Request paths without trailing slash will be appended with a trailing slash. For example, a request with /foo
will be changed to /foo/ before reaching the inner service.